@@ -11,5 +11,9 @@ SEXP C_get_max_threads(void);
 
 SEXP C_set_max_threads(SEXP nthread);
 
+SEXP C_get_initial_device(void);
+
+SEXP C_pause_resource(SEXP hard_pause, SEXP device_num);
+
 #endif  /* _THREAD_CONTROL_H_ */
 
